"""
pdf-cropper.

A simple library that crops pdf and outputs png files.
"""

__version__ = "0.1.4"
__author__ = 'Ali Soltani'
__email__ = 'realalisoltani@gmail.com'
__url__ = 'https://gitlab.com/ali7line/awesome-scripts/-/tree/master/pdfcropper'
__pypi_deps__= ['pyyaml', 'opencv-python', 'numpy', 'pymupdf', 'Pillow']
